bayespy.nodes.VaryingGaussianMarkovChain.plates_multiplier
==========================================================

.. currentmodule:: bayespy.nodes

.. autoattribute:: VaryingGaussianMarkovChain.plates_multiplier